searchData={"items":[{"type":"module","title":"AshSlug","doc":"An extension for slugifying attributes on a resource.","ref":"AshSlug.html"},{"type":"module","title":"AshSlug.Changes","doc":"Change functions for the `AshSlug` extension.","ref":"AshSlug.Changes.html"},{"type":"function","title":"AshSlug.Changes.slugify/2","doc":"Slugify a string attribute on a changeset.","ref":"AshSlug.Changes.html#slugify/2"},{"type":"function","title":"Options - AshSlug.Changes.slugify/2","doc":"* `:attribute` (`t:atom/0`) - Required. The attribute to slugify.\n\n* `:into` (`t:atom/0`) - The attribute to store the slug in. Unless specified, the slug will be stored in the same attribute.\n\n* `:lowercase?` (`t:boolean/0`) - Whether to lowercase the slug. The default value is `true`.\n\n* `:separator` (`t:String.t/0`) - The separator to use between words in the slug. The default value is `\"-\"`.\n\n* `:truncate` (`t:integer/0`) - Truncates the slug at this character length, shortened to the nearest word.\n\n* `:ignore` (one or a list of `t:String.t/0`) - A string or list of strings of characters to ignore when slugifying. The default value is `[]`.","ref":"AshSlug.Changes.html#slugify/2-options"},{"type":"function","title":"Examples - AshSlug.Changes.slugify/2","doc":"change slugify(:text)\n    change slugify(:text, into: :text_slug, lowercase?: false, ignore: [\".\", \"!\"])","ref":"AshSlug.Changes.html#slugify/2-examples"},{"type":"module","title":"AshSlug.Info","doc":"Introspection functions for the `AshSlug` extension.","ref":"AshSlug.Info.html"},{"type":"extras","title":"Home","doc":"![Logo](https://github.com/ash-project/ash/blob/main/logos/cropped-for-header-black-text.png?raw=true#gh-light-mode-only)\n![Logo](https://github.com/ash-project/ash/blob/main/logos/cropped-for-header-white-text.png?raw=true#gh-dark-mode-only)\n\n![Elixir CI](https://github.com/ash-project/ash_slug/workflows/CI/badge.svg)\n[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)\n[![Hex version badge](https://img.shields.io/hexpm/v/ash_slug.svg)](https://hex.pm/packages/ash_slug)\n[![Hexdocs badge](https://img.shields.io/badge/docs-hexdocs-purple)](https://hexdocs.pm/ash_slug)\n\n# AshSlug\n\nAshSlug is an [Ash](https://hexdocs.pm/ash) extension to slugify string attributes on a resource.\n\nThe extension is a thin wrapper around the [Slugify](https://hex.pm/packages/slugify) library, and supports\nthe same options.","ref":"readme.html"},{"type":"extras","title":"Example usage - Home","doc":"```elixir\ndefmodule MyDomain.Resource do\n  @moduledoc false\n\n  use Ash.Resource,\n    domain: MyDomain,\n    data_layer: Ash.DataLayer.Ets,\n    extensions: [AshSlug]\n\n  ets do\n    private?(true)\n  end\n\n  attributes do\n    uuid_primary_key(:id)\n    attribute(:text, :string, public?: true)\n    attribute(:text_slug, :string)\n  end\n\n  actions do\n    create :create do\n      accept([:text])\n      change slugify(:text, into: :text_slug)\n    end\n  end\nend\n```","ref":"readme.html#example-usage"},{"type":"extras","title":"Reference - Home","doc":"- [AshSlug DSL](documentation/dsls/DSL-AshSlug.md)","ref":"readme.html#reference"},{"type":"extras","title":"AshSlug","doc":"<!--\nThis file was generated by Spark. Do not edit it by hand.\n-->\n# AshSlug\n\nAn extension for slugifying attributes on a resource.\n\n\n\n\n\n .spark-required::after { content: \"*\"; color: red !important; }","ref":"dsl-ashslug.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.0"}}